yakumo.cinder.v2.volume_transfer

Package yakumo :: Package cinder :: Package v2 :: Module volume_transfer |
[hide private]
[frames] | no frames]

# Module volume_transfer

source code

Resource class and its manager for volume transfer on Block Storage V2 API

Classes | [hide private]
| Resource resource class for volume transfer on Block Storage V2 API
| Manager manager class for volume transfer on Block Storage V2 API

Variables | [hide private]
| ATTRIBUTE_MAPPING = ``[``(``'``id``'``,` `'``id``'``,` <yakumo.mapper.NoopClass obj`...``
| __package__ = ``'``yakumo.cinder.v2``'``

Variables Details | [hide private]

  ### ATTRIBUTE_MAPPING Value:
      [('id', 'id', mapper.Noop), ('name', 'name', mapper.Noop), ('auth_key'
      , 'auth_key', mapper.Noop), ('volume', 'volume_id', mapper.Resource('c
      inder.volume')), ('created_at', 'created_at', mapper.DateTime),]